#define LLVM_REVISION "499f87882a4ba1837ec12a280478cf4cb0d2753d"
#define LLVM_REPOSITORY "/srcdest/llvm-julia"
